@@ -10,13 +10,9 @@ References
 """
 import os
 from collections import namedtuple
-from math import e
-from .._constants import N_A
 from .utils import to_nums, CASDataReader
 import pandas as pd
 
-F = e*N_A
-
 ### Electrical Conductivity
 
 read = CASDataReader(__file__, 'Electrolytes')
