@@ -38,8 +38,11 @@ from io import open
 from math import log, exp
 from cmath import log as clog, exp as cexp
 import numpy as np
-from ..base import InterpolatedTDependentModel, thermo_model, TDependentHandleBuilder, \
-                   PhaseTHandleBuilder, S, H, Cn
+from ..base import (InterpolatedTDependentModel,
+                    TDependentHandleBuilder, 
+                    PhaseTHandleBuilder, 
+                    thermo_model, 
+                    functor)
 from .utils import to_nums, CASDataReader
 from .._constants import R, calorie
 from ..functional import polylog2
@@ -97,7 +100,7 @@ def CnHS(FCn, FH, FS, data):
 
 def CnHSModel(FCn, FH, FS, data=None, Tmin=None, Tmax=None, name=None):
     funcs = CnHS(FCn, FH, FS, data)
-    return thermo_model(Tmin=Tmin, Tmax=Tmax, name=name, **funcs)
+    return thermo_model(Tmin=Tmin, Tmax=Tmax, name=name, var='Cn', **funcs)
 
 class ZabranskyModelBuilder:
     __slots__ = ('name', 'casdata', 'funcs', 'many')
@@ -129,7 +132,7 @@ _CRC_standard = read('CRC Standard Thermodynamic Properties of Chemical Substanc
 _PerryI = {}
 
 with open(os.path.join(read.folder, 'Perrys Table 2-151.tsv'), encoding='utf-8') as f:
-    '''Read in a dict of heat capacities of irnorganic and elemental solids.
+    """Read in a dict of heat capacities of irnorganic and elemental solids.
     These are in section 2, table 151 in:
     Green, Don, and Robert Perry. Perry's Chemical Engineers' Handbook,
     Eighth Edition. McGraw-Hill Professional, 2007.
@@ -138,7 +141,7 @@ with open(os.path.join(read.folder, 'Perrys Table 2-151.tsv'), encoding='utf-8')
     Cn(Cal/mol/K) = Const + Lin*T + Quadinv/T^2 + Quadinv*T^2
 
     Phases: c, gls, l, g.
-    '''
+    """
     next(f)
     for line in f:
         values = to_nums(line.strip('\n').split('\t'))
@@ -181,9 +184,22 @@ def calculate_Lastovka_Shaw_term(iscyclic_aliphatic, similary_variable):
         term = A2 + (A1-A2)/(1. + exp((similary_variable - A3)/A4))
     return term
 
-@Cn.g(ref="[1]_")
+@functor(var='Cn.g')
 def Lastovka_Shaw(T, MW, similarity_variable, iscyclic_aliphatic=False):
-    r'''
+    r"""
+    Create a functor of temperature (T; in K) that estimates the gas molar 
+    heat capacity (Cn.g; in J/mol/K) of a chemical using the Lastovka Shaw 
+    method, as described in [1]_.
+    
+    Parameters
+    ----------
+    MW : float
+        Molecular weight [g/mol].
+    similarity_variable : float
+        Heat capacity similarity variable [-].
+    iscyclic_aliphatic : bool
+        Whether a chemical is cyclic aliphatic [-].
+    
     Notes
     -----
     The ideal-gas heat capacity (Cn.g; in J/mol/K) is given by:
@@ -222,7 +238,7 @@ def Lastovka_Shaw(T, MW, similarity_variable, iscyclic_aliphatic=False):
     >>> f_Cng(T=400.0)
     33.91574477458602
     
-    '''
+    """
     a = similarity_variable
     term = calculate_Lastovka_Shaw_term(iscyclic_aliphatic, a)
     B11 = 0.73917383
@@ -237,7 +253,7 @@ def Lastovka_Shaw(T, MW, similarity_variable, iscyclic_aliphatic=False):
                  + (B11 + B12*a)*((C11+C12*a)/T)**2*exp(-(C11 + C12*a)/T)/(1.-exp(-(C11+C12*a)/T))**2
                  + (B21 + B22*a)*((C21+C22*a)/T)**2*exp(-(C21 + C22*a)/T)/(1.-exp(-(C21+C22*a)/T))**2)
 
-@H.g
+@functor(var='H.g')
 def Lastovka_Shaw_Integral(Ta, Tb, MW, similarity_variable, iscyclic_aliphatic=False):
     term = calculate_Lastovka_Shaw_term(iscyclic_aliphatic, a)
     return (Lastovka_Shat_Indefinite_Integral(Tb, MW, similarity_variable, term)
@@ -258,7 +274,7 @@ def Lastovka_Shat_Indefinite_Integral(T, MW, similarity_variable, term=None):
                  + C12*a)*exp((-C11 - C12*a)/T)) - (B21 + B22*a)*(-C21 - C22*a)**2/(-C21 
                  - C22*a + (C21 + C22*a)*exp((-C21 - C22*a)/T)))
 
-@S.g
+@functor(var='S.g')
 def Lastovka_Shaw_Integral_Over_T(Ta, Tb, MW, similarity_variable,
                                   iscyclic_aliphatic=False):
     term = calculate_Lastovka_Shaw_term(iscyclic_aliphatic, a)
@@ -287,9 +303,19 @@ def Lastovka_Shaw_Indefinite_Integral_Over_T(T, MW, similarity_variable, term):
     # variable and so will always cancel out.
     return MW * S.real
 
-@Cn.g(ref="[2]_")
+@functor(var='Cn.g')
 def TRCCn(T, a0, a1, a2, a3, a4, a5, a6, a7):
-    r'''
+    r"""
+    Create a functor of temperature (T; in K) that estimates the gas molar 
+    heat capacity (Cn.g; in J/mol/K) of a chemical using the TRCCn method, 
+    as described in [2]_.
+    
+    Parameters
+    ----------
+    a0,a1,a2,a3,a4,a5,a6,a7 : float
+        Regressed coefficients.
+    
+    
     Notes
     -----
     The ideal gas heat capacity (Cn.g; J/mol/K) is given by:
@@ -320,7 +346,7 @@ def TRCCn(T, a0, a1, a2, a3, a4, a5, a6, a7):
     >>> f_Cng(300)
     35.73249522521754
     
-    '''
+    """
     if T <= a7:
         y = 0.
     else:
@@ -343,7 +369,7 @@ def TRCCn_Indefinite_Integral(T, a0, a1, a2, a3, a4, a5, a6, a7):
         h = first*(second + third + fourth + fifth)
     return (a0 + a1*exp(-a2/T)/(a2*T) + h/T)*R*T
 
-@H.g
+@functor(var='H.g')
 def TRCCn_Integral(Ta, Tb, a0, a1, a2, a3, a4, a5, a6, a7):
     return (TRCCn_Indefinite_Integral(Tb, a0, a1, a2, a3, a4, a5, a6, a7)
             - TRCCn_Indefinite_Integral(Ta, a0, a1, a2, a3, a4, a5, a6, a7))
@@ -370,14 +396,24 @@ def TRCCn_Over_T_Indefinite_Integral(T, a0, a1, a2, a3, a4, a5, a6, a7):
         s = first + second + third + fourth
     return a0*log(T) + a1/(a2*a2)*(1. + a2/T)*exp(-a2/T) + s
 
-@S.g
+@functor(var='S.g')
 def TRCCn_Integral_Over_T(Ta, Tb, a0, a1, a2, a3, a4, a5, a6, a7):
     return R*(TRCCn_Over_T_Indefinite_Integral(Tb, a0, a1, a2, a3, a4, a5, a6, a7)
               - TRCCn_Over_T_Indefinite_Integral(Ta, a0, a1, a2, a3, a4, a5, a6, a7))
 
-@Cn.g(ref="[3]_")
+@functor(var='Cn.g')
 def Poling(T, a, b, c, d, e):
     r"""
+    Create a functor of temperature (T; in K) that estimates the gas molar
+    heat capacity (Cn.g; in J/mol/K) of a chemical using the Poling method,
+    as described in [3]_.
+    
+    Parameters
+    ----------
+    a,b,c,d,e : float
+        Regressed coefficients.
+    
+    
     Notes
     -----
     The ideal gas heat capacity (Cn.g; J/mol/K) is given by:
@@ -408,7 +444,7 @@ def Poling(T, a, b, c, d, e):
 def Poling_Indefinite_Integral(T, a, b, c, d, e):
     return (((((0.2*e)*T + 0.25*d)*T + c/3.)*T + 0.5*b)*T + a)*T
 
-@H.g
+@functor(var='H.g')
 def Poling_Integral(Ta, Tb, a, b, c, d, e):
     return R*(Poling_Indefinite_Integral(Tb, a, b, c, d, e)
               - Poling_Indefinite_Integral(Ta, a, b, c, d, e))
@@ -417,7 +453,7 @@ def Poling_Integral(Ta, Tb, a, b, c, d, e):
 def Poling_Over_T_Indefinite_Integral(T, a, b, c, d, e):
     return ((((0.25*e)*T + d/3.)*T + 0.5*c)*T + b)*T
 
-@S.g
+@functor(var='S.g')
 def Poling_Integral_Over_T(Ta, Tb, a, b, c, d, e):
     return R*(Poling_Over_T_Indefinite_Integral(Tb, a, b, c, d, e)
               - Poling_Over_T_Indefinite_Integral(Ta, a, b, c, d, e)
@@ -470,9 +506,22 @@ def heat_capacity_gas_handle(handle, CAS, MW, similarity_variable, iscyclic_alip
     
 ### Heat capacities of liquids
 
-@Cn.l(ref="[3]_")
+@functor(var='Cn.l')
 def Rowlinson_Poling(T, Tc, ω, Cn_g):
-    r'''
+    r"""
+    Create a functor of temperature (T; in K) that estimates the liquid molar
+    heat capacity (Cn.l; in J/mol/K) of a chemical using the Rowlinson Poling
+    method, as described in [3]_.
+    
+    Parameters
+    ----------
+    Tc : float
+        Critical point temperature [K].
+    ω : float
+        Acentric factor [-].
+    Cn_g : float
+        Gas molar heat capacity [-].
+    
     Notes
     -----
     The heat capacity of a liquid is given by:
@@ -499,13 +548,27 @@ def Rowlinson_Poling(T, Tc, ω, Cn_g):
     >>> f_Cnl(100)
     55.99104104081243
     
-    '''
+    """
     Tr = T/Tc
     return Cn_g(T) + R*(1.586 + 0.49/(1.-Tr) + ω*(4.2775 + 6.3*(1-Tr)**(1/3.)/Tr + 0.4355/(1.-Tr)))
 
-@Cn.l(ref="[3]_ [4]_ [5]_")
+@functor(var='Cn.l')
 def Rowlinson_Bondi(T, Tc, ω, Cn_g):
-    r'''
+    r"""
+    Create a functor of temperature (T; in K) that estimates the liquid molar
+    heat capacity (Cn.l; in J/mol/K) of a chemical using the Rowlinson Bondi
+    method, as described in [3]_ [4]_ [5]_.
+    
+    Parameters
+    ----------
+    Tc : float
+        Critical point temperature [K].
+    ω : float
+        Acentric factor [-].
+    Cn_g : float
+        Gas molar heat capacity [-].
+    
+    
     Notes
     -----
     The heat capacity of a liquid is given by:
@@ -530,13 +593,24 @@ def Rowlinson_Bondi(T, Tc, ω, Cn_g):
     >>> f_Cnl(100)
     55.986088530998174
       
-    '''
+    """
     Tr = T/Tc
     return Cn_g(T) + R*(1.45 + 0.45/(1.-Tr) + 0.25*ω*(17.11 + 25.2*(1-Tr)**(1/3.)/Tr + 1.742/(1.-Tr)))
 
-@Cn.l(ref="[6]_")
+@functor(var='Cn.l')
 def Dadgostar_Shaw(T, MW, similarity_variable):
-    r'''
+    r"""
+    Create a functor of temperature (T; in K) that estimates the liquid molar
+    heat capacity (Cn.l; in J/mol/K) of a chemical using the Dadgostar Shaw
+    method, as described in [6]_.
+    
+    Parameters
+    ----------
+    MW : float
+        Molecular weight [g/mol].
+    similarity_variable : float
+        Heat capacity similarity variable [-].
+    
     Notes
     -----
     The liquid heat capacity is given by:
@@ -547,14 +621,16 @@ def Dadgostar_Shaw(T, MW, similarity_variable):
         
         C_n = MW \cdot Cp
 
-    Where :math:`\alpha` is the similarity variable. There are many restrictions on its use.
+    Where :math:`\alpha` is the similarity variable. There are many 
+    restrictions on its use.
 
-    Original model is in terms of J/g/K, but it has been modified to give molar heat capacity in J/mol/K.
+    Original model is in terms of J/g/K, but it has been modified to give 
+    molar heat capacity in J/mol/K.
 
     a11 = -0.3416; a12 = 2.2671; a21 = 0.1064; a22 = -0.3874l;
     a31 = -9.8231E-05; a32 = 4.182E-04
       
-    '''
+    """
     first, second, third = calculate_Dadgostar_Shaw_terms(MW, similarity_variable)
     first *= 3*R*(151.8675/T)**2*exp(151.8675/T)/(exp(151.8675/T)-1)**2
     return (first + second*T + third*T**2) * MW
@@ -582,7 +658,7 @@ def Dadgostar_Shaw_Indefinte_Integral(T, first, second, third):
     first *= 3*R*(151.8675/T)**2*exp(151.8675/T)/(exp(151.8675/T)-1)**2
     return T2*T/3.*third + T2*0.5*second + T*first
 
-@H.l
+@functor(var='H.l')
 def Dadgostar_Shaw_Integral(Ta, Tb, MW, similarity_variable):
     terms = calculate_Dadgostar_Shaw_terms(MW, similarity_variable)
     return MW*(Dadgostar_Shaw_Indefinte_Integral(Tb, *terms)
@@ -593,7 +669,7 @@ def Dadgostar_Shaw_Over_T_Indefinte_Integral(T, first, second, third):
     first *= 3*R*(151.8675/T)**2*exp(151.8675/T)/(exp(151.8675/T)-1)**2
     return T*T*0.5*third + T*second + first*log(T)
 
-@H.l
+@functor(var='S.l')
 def Dadgostar_Shaw_Over_T_Integral(Ta, Tb, MW, similarity_variable):
     terms = calculate_Dadgostar_Shaw_terms(MW, similarity_variable)
     return MW*(Dadgostar_Shaw_Over_T_Indefinte_Integral(Tb, *terms)
@@ -633,9 +709,20 @@ with open(os.path.join(read.folder, 'Zabransky.tsv'), encoding='utf-8') as f:
             # No duplicates for quasipolynomials
             d[CAS] = (Tc, a1p, a2p, a3p, a4p, a5p, a6p, Tmin, Tmax)
 
-@Cn.l(ref="[7]_")
+@functor(var='Cn.l')
 def Zabransky_Quasi_Polynomial(T, Tc, a1, a2, a3, a4, a5, a6):
     r"""
+    Create a functor of temperature (T; in K) that estimates the liquid molar
+    heat capacity (Cn.l; in J/mol/K) of a chemical using the Zabransky Quasi
+    Polynomial method, as described in [7]_.
+    
+    Parameters
+    ----------
+    Tc : float
+        Critical point temperature [K].
+    a1,a2,a3,a4,a5,a6 : float
+        Regressed coefficients.
+    
     Notes
     -----
     The liquid heat capacity is given by:
@@ -661,7 +748,7 @@ def Zabransky_Quasi_Polynomial_Indefinte_Integral(T, Tc, a1, a2, a3, a4, a5, a6)
     return R*(T*(T*(T*(T*a6/(4.*Tc3) + a5/(3.*Tc2)) + a4/(2.*Tc)) - a1 + a3) 
               + T*a1*log(1. - T/Tc) - 0.5*Tc*(a1 + a2)*log(term))
 
-@H.l
+@functor(var='H.l')
 def Zabransky_Quasi_Polynomial_Integral(Ta, Tb, Tc, a1, a2, a3, a4, a5, a6):
     return (Zabransky_Quasi_Polynomial_Indefinte_Integral(Tb, Tc, a1, a2, a3, a4, a5, a6)
             - Zabransky_Quasi_Polynomial_Indefinte_Integral(Ta, Tc, a1, a2, a3, a4, a5, a6))
@@ -675,14 +762,23 @@ def Zabransky_Quasi_Polynomial_Over_T_Indefinte_Integral(T, Tc, a1, a2, a3, a4,
     return R*(a3*logT -a1*polylog2(T/Tc) - a2*(-logT + 0.5*log(term*term))
               + T*(T*(T*a6/(3.*Tc3) + a5/(2.*Tc2)) + a4/Tc))
 
-@S.l
+@functor(var='S.l')
 def Zabransky_Quasi_Polynomial_Over_T_Integral(Ta, Tb, Tc, a1, a2, a3, a4, a5, a6):
     return (Zabransky_Quasi_Polynomial_Over_T_Indefinte_Integral(Tb, Tc, a1, a2, a3, a4, a5, a6)
             - Zabransky_Quasi_Polynomial_Over_T_Indefinte_Integral(Ta, Tc, a1, a2, a3, a4, a5, a6))
 
-@Cn.l(ref='[7]_')
+@functor(var='Cn.l')
 def Zabransky_Cubic(T, a1, a2, a3, a4):
     r"""
+    Create a functor of temperature (T; in K) that estimates the liquid molar
+    heat capacity (Cn.l; in J/mol/K) of a chemical using the Zabransky Cubic
+    method, as described in [7]_.
+    
+    Parameters
+    ----------
+    a1,a2,a3,a4 : float
+        Regressed coefficients.
+    
     Notes
     -----
     The liquid heat capacity is given by:
@@ -699,7 +795,7 @@ def Zabransky_Cubic_Indefinite_Integral(T, a1, a2, a3, a4):
     T = T/100.
     return 100.*R*T*(T*(T*(T*a4*0.25 + a3/3.) + a2*0.5) + a1)
 
-@H.l
+@functor(var='H.l')
 def Zabransky_Cubic_Integral(Ta, Tb, a1, a2, a3, a4):
     return (Zabransky_Cubic_Indefinite_Integral(Tb, a1, a2, a3, a4)
             - Zabransky_Cubic_Indefinite_Integral(Ta, a1, a2, a3, a4))
@@ -709,7 +805,7 @@ def Zabransky_Cubic_Over_T_Indefinite_Integral(T, a1, a2, a3, a4):
     T = T/100.
     return R*(T*(T*(T*a4/3. + a3/2.) + a2) + a1*log(T))
 
-@S.l
+@functor(var='S.l')
 def Zabransky_Cubic_Over_T_Integral(Ta, Tb, a1, a2, a3, a4):
     return (Zabransky_Cubic_Over_T_Indefinite_Integral(Tb, a1, a2, a3, a4)
             - Zabransky_Cubic_Over_T_Indefinite_Integral(Ta, a1, a2, a3, a4))
@@ -792,9 +888,20 @@ def heat_capacity_liquid_handle(handle, CAS, Tb, Tc, omega, MW, similarity_varia
 
 # %% Heat Capacity Solid
 
-@Cn.s(ref="[8]_")
+@functor(var='Cn.s')
 def Lastovka_Solid(T, similarity_variable, MW):
-    r'''
+    r"""
+    Create a functor of temperature (T; in K) that estimates the solid molar 
+    heat capacity (Cn.s; in J/mol/K) of a chemical using the Lastovka Solid
+    method, as described in [8]_.
+    
+    Parameters
+    ----------
+    similarity_variable : float
+        Heat capacity similarity variable [-].
+    MW : float
+        Molecular weight [g/mol].
+    
     Notes
     -----
     The solid heat capacity is given by:
@@ -831,7 +938,7 @@ def Lastovka_Solid(T, similarity_variable, MW):
     >>> f(150)
     42.196379547807
     
-    '''
+    """
     A1 = 0.013183
     A2 = 0.249381
     theta = 151.8675
@@ -861,7 +968,7 @@ def Lastovka_Solid_Indefinite_Integral(T, similarity_variable, MW):
         + 3. * (A1*R*similarity_variable*theta
         + A2*R*sim2*theta)/(exp(theta/T) - 1.))
 
-@H.s
+@functor(var='H.s')
 def Lastovka_Solid_Integral(Ta, Tb, similarity_variable, MW):
     return (Lastovka_Solid_Indefinite_Integral(Tb, similarity_variable, MW)
             - Lastovka_Solid_Indefinite_Integral(Ta, similarity_variable, MW))
@@ -885,15 +992,23 @@ def Lastovka_Solid_Over_T_Indefinite_Integral(T, similarity_variable, MW):
                  + (3.*A1*R*similarity_variable*theta 
                     + 3.*A2*R*sim2*theta)/T)
  
-@S.s
+@functor(var='S.s')
 def Lastovka_Solid_Over_T_Integral(Ta, Tb, similarity_variable, MW):
     return (Lastovka_Solid_Over_T_Indefinite_Integral(Tb, similarity_variable, MW)
             - Lastovka_Solid_Over_T_Indefinite_Integral(Ta, similarity_variable, MW))
     
     
-@Cn.s(ref='[9]_')
+@functor(var='Cn.s')
 def Perry_151(T, a, b, c, d):
     r"""
+    Create a functor of temperature (T; in K) that estimates the solid molar 
+    heat capacity (Cn.s; in J/mol/K) of a chemical using the Perry 151 method,
+    as described in [9]_.
+    
+    Parameters
+    ----------
+    a,b,c,d : float
+        Regressed coefficients.
     
     Notes
     -----
@@ -901,18 +1016,19 @@ def Perry_151(T, a, b, c, d):
     
     .. math:: C_n = 4.184 (a + bT + \frac{c}{T^2} + dT^2)
     
-    Coefficients are listed in section 2, table 151 of [9]_. Note that the original model was in a Calorie basis, but has been translated to Joules.
+    Coefficients are listed in section 2, table 151 of [9]_. Note that the
+    original model was in a Calorie basis, but has been translated to Joules.
     
     """
     return (a + b*T + c/T**2 + d*T**2)*calorie
 
-@H.s
+@functor(var='H.s')
 def Perry_151_Integral(Ta, Tb, a, b, c, d):
     H1 = (a*Ta + 0.5*b*Ta**2 - d/Ta + c*Ta**3/3.)
     H2 = (a*Tb + 0.5*b*Tb**2 - d/Tb + c*Tb**3/3.)
     return (H2 - H1)*calorie
 
-@S.s
+@functor(var='S.s')
 def Perry_151_Over_T_Integral(Ta, Tb, a, b, c, d):
     S1 = a*log(Ta) + b*Ta - d/(2.*Ta**2) + 0.5*c*Ta**2
     S2 = a*log(Tb) + b*Tb - d/(2.*Tb**2) + 0.5*c*Tb**2
