@@ -34,7 +34,7 @@ References
         91:5 (February 1, 1993).
 
 """
-from ..base import Psat, TDependentHandleBuilder
+from ..base import functor, TDependentHandleBuilder
 from .dippr import DIPPR_EQ101
 from .utils import CASDataReader
 from math import log, exp
@@ -52,9 +52,18 @@ _VDI_PPDS_3 = read("VDI PPDS Boiling temperatures at different pressures.tsv")
 
 # %% Vapor pressure
 
-@Psat(ref="[1]_")
+@functor(var='Psat')
 def Antoine(T, a, b, c):
     r"""
+    Create a functor of temperature (T; in K) that estimates the saturated 
+    vapor pressure (Psat; in Pa) of a chemical using the Antoine method, as 
+    described in [1]_.
+    
+    Parameters
+    ----------
+    a,b,c : float
+        Regressed coefficients.
+    
     Notes
     -----
     The vapor pressure (Psat; in Pa) is given by:
@@ -100,9 +109,20 @@ def Antoine(T, a, b, c):
     """
     return 10.0**(a - b / (T + c))
 
-@Psat(ref="[2]_")
+@functor(var='Psat')
 def TRC_Extended_Antoine(T, Tc, to, a, b, c, n, e, f):
     r"""
+    Create a functor of temperature (T; in K) that estimates the saturated 
+    vapor pressure (Psat; in Pa) of a chemical using the TRC Extended 
+    Antoine method, as described in [2]_.
+    
+    Parameters
+    ----------
+    Tc : float
+        Critical point temperature [K].
+    to,a,b,c,n,e,f : float
+        Regressed coefficients.
+    
     Notes
     -----
     The vapor pressure (Psat; in Pa) is given by:
@@ -140,9 +160,22 @@ def TRC_Extended_Antoine(T, Tc, to, a, b, c, n, e, f):
     x = max((T - to - 273.15) / Tc, 0.0)
     return 10.0**(a - b / (T + c) + 0.43429 * x**n + e * x**8 + f * x**12)
 
-@Psat(ref="[2]_")
+@functor(var='Psat')
 def Wagner_McGraw(T, Tc, Pc, a, b, c, d):
     r"""
+    Create a functor of temperature (T; in K) that estimates the saturated
+    vapor pressure (Psat; in Pa) of a chemical using the Wagner McGraw method,
+    as described in [2]_.
+    
+    Parameters
+    ----------
+    Tc : float
+        Critical point temperature [K].
+    Pc : float
+        Critical point pressure [Pa].
+    a,b,c,d : float
+        Regressed coefficients.
+    
     Notes
     -----
     The vapor pressure (Psat; in Pa) is given by:
@@ -178,9 +211,22 @@ def Wagner_McGraw(T, Tc, Pc, a, b, c, d):
     tau = 1.0 - Tr
     return Pc * exp((a * tau + b * tau**1.5 + c * tau**3 + d * tau**6) / Tr)
 
-@Psat(ref="[5]_")
+@functor(var='Psat')
 def Wagner(T, Tc, Pc, a, b, c, d):
     r"""
+    Create a functor of temperature (T; in K) that estimates the saturated 
+    vapor pressure (Psat; in Pa) of a chemical using the Wagner method, as 
+    described in [5]_.
+    
+    Parameters
+    ----------
+    Tc : float
+        Critical point temperature [K].
+    Pc : float
+        Critical point pressure [Pa].
+    a,b,c,d : float
+        Regressed coefficients.
+    
     Notes
     -----
     The vapor pressure (Psat; in Pa) is given by:
@@ -215,9 +261,22 @@ def Wagner(T, Tc, Pc, a, b, c, d):
     τ = 1.0 - Tr
     return Pc * exp((a*τ + b*τ**1.5 + c*τ**2.5 + d*τ**5) / Tr)
 
-@Psat(ref="[6]_")
+@functor(var='Psat')
 def Boiling_Critical_Relation(T, Tb, Tc, Pc):
     r"""
+    Create a functor of temperature (T; in K) that estimates the saturated
+    vapor pressure (Psat; in Pa) of a chemical using the Boiling Critical 
+    Relation method, as described in [6]_.
+    
+    Parameters
+    ----------
+    Tb : float
+        Boiling point temperature [K].
+    Tc : float
+        Critical point temperature [K].
+    Pc : float
+        Critical point pressure [Pa].
+    
     Notes
     -----
     The vapor pressure (Psat; in Pa) is given by:
@@ -246,9 +305,22 @@ def calculate_Boiling_Critical_Relation_term(Tb, Tc, Pc):
     h = Tbr * log(Pc / 101325.0) / (1 - Tbr)
     return h, Tbr
 
-@Psat(ref="[7]_")
+@functor(var='Psat')
 def Lee_Kesler(T, Tc, Pc, ω):
     r"""
+    Create a functor of temperature (T; in K) that estimates the saturated 
+    vapor pressure (Psat; in Pa) of a chemical using the Lee Kesler method,
+    as described in [7]_.
+    
+    Parameters
+    ----------
+    Tc : float
+        Critical point temperature [K].
+    Pc : float
+        Critical point pressure [Pa].
+    ω : float
+        Acentric factor [-].
+    
     Notes
     -----
     The vapor pressure (Psat; in Pa) is given by:
@@ -279,9 +351,22 @@ def Lee_Kesler(T, Tc, Pc, ω):
     f1 = 15.2518 - 15.6875 / Tr - 13.4721 * logTr + 0.43577 * Tra
     return exp(f0 + ω * f1) * Pc
 
-@Psat(ref="[8]_")
+@functor(var='Psat')
 def Ambrose_Walton(T, Tc, Pc, ω):
     r"""
+    Create a functor of temperature (T; in K) that estimates the saturated 
+    vapor pressure (Psat; in Pa) of a chemical using the Ambrose Walton 
+    method, as described in [8]_.
+    
+    Parameters
+    ----------
+    Tc : float
+        Critical point temperature [K].
+    Pc : float
+        Critical point pressure [Pa].
+    ω : float
+        Acentric factor [-].
+    
     Notes
     -----
     The vapor pressure (Psat; in Pa) is given by:
@@ -317,9 +402,22 @@ def Ambrose_Walton(T, Tc, Pc, ω):
     f2 = -0.64771 * τ + 2.41539 * τa - 4.26979 * τb + 3.25259 * τc
     return Pc * exp((f0 + f1 * ω + f2 * ω**2) / Tr)
 
-@Psat(ref="[9]_")
+@functor(var='Psat')
 def Sanjari(T, Tc, Pc, ω):
     r"""
+    Create a functor of temperature (T; in K) that estimates the saturated 
+    vapor pressure (Psat; in Pa) of a chemical using the Sanjari method, as 
+    described in [9]_.
+    
+    Parameters
+    ----------
+    Tc : float
+        Critical point temperature [K].
+    Pc : float
+        Critical point pressure [Pa].
+    ω : float
+        Acentric factor [-].
+    
     Notes
     -----
     The vapor pressure (Psat; in Pa) is given by:
@@ -365,9 +463,22 @@ def Sanjari(T, Tc, Pc, ω):
     f2 = 18.19967 + 16.33839 / Tr + 65.6995 * logTr + -35.9739 * Ta
     return Pc * exp(f0 + f1 * ω + f2 * ω**2)
 
-@Psat(ref="[10]_")
+@functor(var='Psat')
 def Edalat(T, Tc, Pc, ω):
     r"""
+    Create a functor of temperature (T; in K) that estimates the saturated
+    vapor pressure (Psat; in Pa) of a chemical using the Edalat method, as 
+    described in [10]_.
+    
+    Parameters
+    ----------
+    Tc : float
+        Critical point temperature [K].
+    Pc : float
+        Critical point pressure [Pa].
+    ω : float
+        Acentric factor [-].
+    
     Notes
     -----
     The vapor pressure (Psat; in Pa) is given by:
