@@ -54,7 +54,7 @@ from .virial import BVirial_Pitzer_Curl, BVirial_Abbott, BVirial_Tsonopoulos, BV
 from .miscdata import VDI_saturation_dict, VDI_tabular_data
 from .dippr import DIPPR_EQ105
 # from .electrochem import _Laliberte_Density_ParametersDict, Laliberte_Density
-from ..base import (V, InterpolatedTDependentModel, 
+from ..base import (functor, InterpolatedTDependentModel, 
                     TPDependentModel, TPDependentHandleBuilder,
                     PhaseTPHandleBuilder, ThermoModelHandle)
 
@@ -90,9 +90,22 @@ _CRC_virial = read('CRC Virial polynomials.tsv')
 
 # %% Liquids
 
-@V.l(ref="[1]_")
+@functor(var='V.l')
 def Yen_Woods(T, Tc, Vc, Zc):
-    r'''
+    r"""
+    Create a functor of temperature (T; in K) that estimates the liquid molar 
+    volume (V.l; in m^3/mol) of a chemical using the Yen Woods method, as 
+    described in [1]_.
+    
+    Parameters
+    ----------
+    Tc : float
+        Critical point temperature [K].
+    Vc : float
+        Critical point volume [m^3/mol].
+    Zc : float
+        Critical compressibility [-].
+    
     Notes
     -----
     The molar volume of a liquid is given by:
@@ -120,15 +133,10 @@ def Yen_Woods(T, Tc, Vc, Zc):
     Examples
     --------
     >>> f = Yen_Woods(Tc=647.14, Vc=5.6e-05, Zc=0.2294728175007233)
-    >>> f.show()
-    Functor: Yen_Woods(T, P=None) -> V.l [m^3/mol]
-     Tc: 647.14 K
-     Vc: 5.6e-05 m^3/mol
-     Zc: 0.22947
     >>> f(300)
     1.7715316221999628e-05
 
-    '''
+    """
     Tr = T/Tc
     A, B, D = calculate_Yen_Woods_terms(Tc, Vc, Zc)
     return Vc/(1 + A*(1-Tr)**(1/3.) + B*(1-Tr)**(2/3.) + D*(1-Tr)**(4./3.))
@@ -144,9 +152,22 @@ def calculate_Yen_Woods_terms(Tc, Vc, Zc):
     D = 0.93 - B
     return (A, B, D)
 
-@V.l(ref='[2]_')
+@functor(var='V.l')
 def Rackett(T, Tc, Pc, Zc):
-    r'''
+    r"""
+    Create a functor of temperature (T; in K) that estimates the liquid molar 
+    volume (V.l; in m^3/mol) of a chemical using the Rackett method, as 
+    described in [2]_.
+    
+    Parameters
+    ----------
+    Tc : float
+        Critical point temperature [K].
+    Pc : float
+        Critical point pressure [Pa].
+    Zc : float
+        Critical compressibility [-].
+    
     Notes
     -----
     The molar volume of a liquid is given by:
@@ -161,20 +182,28 @@ def Rackett(T, Tc, Pc, Zc):
     Propane, example from the API Handbook
 
     >>> f = Rackett(Tc=369.83, Pc=4248000.0, Zc=0.2763)
-    >>> f.show()
-    Functor: Rackett(T, P=None) -> V.l [m^3/mol]
-     Tc: 369.83 K
-     Pc: 4.248e+06 Pa
-     Zc: 0.2763
     >>> f(T=272.03889)
     8.299222192473635e-05
 
-    '''
+    """
     return R*Tc/Pc*Zc**(1. + (1. - T/Tc)**(2./7.))
 
-@V.l(ref='[3]_ [4]_')
+@functor(var='V.l')
 def Yamada_Gunn(T, P, Tc, Pc, omega):
-    r'''
+    r"""
+    Create a functor of temperature (T; in K) and pressure (P; in Pa) that 
+    estimates the liquid molar volume (V.l; in m^3/mol) of a chemical using 
+    the Yamada Gunn method, as described in [3]_ [4]_.
+    
+    Parameters
+    ----------
+    Tc : float
+        Critical point temperature [K].
+    Pc : float
+        Critical point pressure [Pa].
+    omega : float
+        Acentric factor [-].
+        
     Notes
     -----
     The molar volume of a liquid is given by:
@@ -190,15 +219,10 @@ def Yamada_Gunn(T, P, Tc, Pc, omega):
     Examples
     --------
     >>> f = Yamada_Gunn(Tc=647.14, Pc=22048320.0, omega=0.344)
-    >>> f.show()
-    Functor: Yamada_Gunn(T, P) -> V.l [m^3/mol]
-     Tc: 647.14 K
-     Pc: 2.2048e+07 Pa
-     omega: 0.344
     >>> f(T=300, P=101325)
     1.9511311612842117e-08
 
-    '''
+    """
     k1, k2 = calculate_Yamada_Gunn_terms(Tc, Pc, omega)
     return k1 * k2**(1 + (1 - T/Tc)**(2/7.))
 
@@ -207,9 +231,22 @@ def calculate_Yamada_Gunn_terms(Tc, Pc, omega):
     k2 = (0.29056 - 0.08775*omega)
     return k1, k2
 
-@V.l(ref="[5]_")
+@functor(var='V.l')
 def Townsend_Hales(T, Tc, Vc, omega):
-    r'''
+    r"""
+    Create a functor of temperature (T; in K) that estimates the liquid molar 
+    volume (V.l; in m^3/mol) of a chemical using the Townsend Hales method,
+    as described in [5]_.
+    
+    Parameters
+    ----------
+    Tc : float
+        Critical point temperature [K].
+    Vc : float
+        Critical point volume [m^3/mol].
+    omega : float
+        Acentric factor [-].
+    
     Notes
     -----
     The density of a saturated liquid is given by:
@@ -225,15 +262,10 @@ def Townsend_Hales(T, Tc, Vc, omega):
     Calculate the molar volume of water at 300 K:
     
     >>> f = Townsend_Hales(Tc=647.14, Vc=5.6e-05, omega=0.344)
-    >>> f.show()
-    Functor: Townsend_Hales(T, P=None) -> V.l [m^3/mol]
-     Tc: 647.14 K
-     Vc: 5.6e-05 m^3/mol
-     omega: 0.344
     >>> f(T=300)
     1.8027637900666407e-05
 
-    '''
+    """
     Tr = T/Tc
     return Vc/(1 + 0.85*(1-Tr) + (1.692 + 0.986*omega)*(1-Tr)**(1/3.))
 
@@ -251,9 +283,22 @@ Bhirud_normal_lnU0_interp = interp1d(Bhirud_normal_Trs,
 Bhirud_normal_lnU1_interp = interp1d(Bhirud_normal_Trs,
                                      Bhirud_normal_lnU1, kind='cubic')
 
-@V.l(ref='[6]_')
+@functor(var='V.l')
 def Bhirud_Normal(T, Tc, Pc, omega):
-    r'''
+    r"""
+    Create a functor of temperature (T; in K) that estimates the liquid molar 
+    volume (V.l; in m^3/mol) of a chemical using the Bhirud Normal method, as 
+    described in [6]_.
+    
+    Parameters
+    ----------
+    Tc : float
+        Critical point temperature [K].
+    Pc : float
+        Critical point pressure [Pa].
+    omega : float
+        Acentric factor [-].
+    
     Notes
     -----
     The density of a liquid is given by:
@@ -277,15 +322,10 @@ def Bhirud_Normal(T, Tc, Pc, omega):
     Calculate the molar volume of water at 300 K:
 
     >>> f = Bhirud_Normal(Tc=647.14, Pc=22048320.0, omega=0.344)
-    >>> f.show()
-    Functor: Bhirud_Normal(T, P=None) -> V.l [m^3/mol]
-     Tc: 647.14 K
-     Pc: 2.2048e+07 Pa
-     omega: 0.344
     >>> f(T=300)
     2.069232443882547e-05
 
-    '''
+    """
     Tr = T/Tc
     if Tr <= 0.98:
         lnU0 = 1.39644 - 24.076*Tr + 102.615*Tr**2 - 255.719*Tr**3 \
@@ -301,9 +341,22 @@ def Bhirud_Normal(T, Tc, Pc, omega):
     Unonpolar = exp(lnU0 + omega*lnU1)
     return (Unonpolar*R*T)/Pc
 
-@V.l(ref='[7]_')
+@functor(var='V.l')
 def Costald(T, Tc, Vc, omega):
-    r'''
+    r"""
+    Create a functor of temperature (T; in K) that estimates the liquid molar 
+    volume (V.l; in m^3/mol) of a chemical using the Costald method, as 
+    described in [7]_.
+    
+    Parameters
+    ----------
+    Tc : float
+        Critical point temperature [K].
+    Vc : float
+        Critical point volume [m^3/mol].
+    omega : float
+        Acentric factor [-].
+    
     Notes
     -----
     A popular and accurate estimation method. If possible, fit parameters are
@@ -332,15 +385,10 @@ def Costald(T, Tc, Vc, omega):
     Calculate the volume of water at 300 K and 1 atm:
     
     >>> f = Costald(Tc=647.14, Vc=5.6e-05, omega=0.344)
-    >>> f.show()
-    Functor: Costald(T, P=None) -> V.l [m^3/mol]
-     Tc: 647.14 K
-     Vc: 5.6e-05 m^3/mol
-     omega: 0.344
     >>> f(T=300, P=101325)
     1.8188550933914777e-05
     
-    '''
+    """
     Tr = T/Tc
     V_delta = (-0.296123 + 0.386914*Tr - 0.0427258*Tr**2
         - 0.0480645*Tr**3)/(Tr - 1.00001)
@@ -348,9 +396,28 @@ def Costald(T, Tc, Vc, omega):
         - 0.81446*(1-Tr) + 0.190454*(1-Tr)**(4/3.)
     return Vc*V_0*(1-omega*V_delta)
 
-@V.l(ref='[8]_', method='Campbell-Thodos CSP')
+@functor(var='V.l')
 def Campbell_Thodos(T, Tb, Tc, Pc, MW, dipole=None, has_hydroxyl=False):
-    r'''
+    r"""
+    Create a functor of temperature (T; in K) that estimates the liquid molar
+    volume (V.l; in m^3/mol) of a chemical using the Campbell-Thodos CSP 
+    method, as described in [8]_.
+    
+    Parameters
+    ----------
+    Tb : float
+        Boiling point temperature [K].
+    Tc : float
+        Critical point temperature [K].
+    Pc : float
+        Critical point pressure [Pa].
+    MW : float
+        Molecular weight [g/mol].
+    dipole : float
+        Dipole momment [Debye].
+    has_hydroxyl : float
+        Whether a polar chemical has hydroxyl groups [-].
+    
     Notes
     -----
     An old and uncommon estimation method.
@@ -395,18 +462,10 @@ def Campbell_Thodos(T, Tb, Tc, Pc, MW, dipole=None, has_hydroxyl=False):
     Calculate the volume of water at 300 K:   
     
     >>> f = Campbell_Thodos(Tb=373.124, Tc=647.14, Pc=22048320.0, MW=18.02, dipole=1.85, has_hydroxyl=True)
-    >>> f.show()
-    Functor: Campbell_Thodos(T, P=None) -> V.l [m^3/mol]
-     Tb: 373.12 K
-     Tc: 647.14 K
-     Pc: 2.2048e+07 Pa
-     MW: 18.02 g/mol
-     dipole: 1.85 Debye
-     has_hydroxyl: 1
     >>> f(T=300, P=101325)
     1.8048013082120765e-05
     
-    '''
+    """
     Pc = Pc/101325.
     Tr = T/Tc
     Tbr = Tb/Tc
@@ -427,9 +486,24 @@ def Campbell_Thodos(T, Tb, Tc, Pc, MW, dipole=None, has_hydroxyl=False):
     Vs = R*Tc/(Pc*101325)*Zra**(1+(1-Tr)**(2./7.))
     return Vs
 
-@V.l(method='Mchaweh-Moshfeghian', ref='[9]_')
+@functor(var='V.l')
 def SNM0(T, Tc, Vc, omega, delta_SRK):
-    r'''
+    r"""
+    Create a functor of temperature (T; in K) that estimates the liquid molar 
+    volume (V.l; in m^3/mol) of a chemical using the Mchaweh-Moshfeghian 
+    method, as described in [9]_.
+    
+    Parameters
+    ----------
+    Tc : float
+        Critical point temperature [K].
+    Vc : float
+        Critical point volume [m^3/mol].
+    omega : float
+        Acentric factor [-].
+    delta_SRK : float
+        Regressed coefficient.
+    
     Notes
     -----
     .. math::
@@ -459,7 +533,7 @@ def SNM0(T, Tc, Vc, omega, delta_SRK):
     >>> f(121)
     3.493288100008123e-05
     
-    '''
+    """
     m = calculate_SNM0_term(omega)
     Tr = T/Tc
     alpha_SRK = (1. + m*(1. - Tr**0.5))**2
@@ -472,9 +546,12 @@ def SNM0(T, Tc, Vc, omega, delta_SRK):
 def calculate_SNM0_term(omega):
     return 0.480 + 1.574*omega - 0.176*omega*omega
 
-@V.l(doc='auto-header')
+@functor(var='V.l')
 def CRC_Inorganic(T, rho0, k, Tm, MW):
-    r'''
+    r"""
+    Create a functor of temperature (T; in K) that estimates the liquid molar 
+    volume (V.l; in m^3/mol) of a chemical using the CRC Inorganic method.
+    
     Parameters
     ----------
     T : float
@@ -514,19 +591,36 @@ def CRC_Inorganic(T, rho0, k, Tm, MW):
     2206.30796
 
     
-    '''
+    """
     f = MW/1000
     return (rho0 - k*(T-Tm))*f
 
-@V.l
+@functor(var='V.l')
 def VDI_PPDS(T, Tc, rhoc, MW, a, b, c, d):
     tau = 1. - T/Tc
     rho = rhoc + a*tau**0.35 + b*tau**(2/3.) + c*tau + d*tau**(4/3.)
     return fn.rho_to_V(rho, MW)
    
-@V.l(ref="[11]_")
+@functor(var='V.l')
 def Costald_Compressed(T, P, Psat, Tc, Pc, omega, V):
-    r'''
+    r"""
+    Create a functor of temperature (T; in K) and pressure (P; in Pa) that 
+    estimates the liquid molar volume (V.l; in m^3/mol) of a chemical using
+    the Costald Compressed method, as described in [11]_.
+    
+    Parameters
+    ----------
+    Psat : float
+        Saturated vapor pressure [Pa].
+    Tc : float
+        Critical point temperature [K].
+    Pc : float
+        Critical point pressure [Pa].
+    omega : float
+        Acentric factor [-].
+    V : float
+        Molar volume [m^3/mol].
+    
     Notes
     -----
     The molar volume of a liquid is given by:
@@ -552,7 +646,7 @@ def Costald_Compressed(T, P, Psat, Tc, Pc, omega, V):
     >>> f(303.)
     9.287482879788506e-05
     
-    '''
+    """
     a = -9.070217
     b = 62.45326
     d = -135.1102
@@ -640,24 +734,24 @@ ideal_gas_model = TPDependentModel(ideal_gas,
                                    0, 10e12,
                                    var='V.g')
 
-@V.g
+@functor(var='V.g')
 def Tsonopoulos_extended(T, P, Tc, Pc, omega, a=0, b=0,
                          species_type='', dipole=0, order=0):
     return ideal_gas(T, P) + BVirial_Tsonopoulos_extended(T, Tc, Pc, omega, a, b,
                                                           species_type, dipole, order)
-@V.g 
+@functor(var='V.g') 
 def Tsonopoulos(T, P, Tc, Pc, omega):
     return ideal_gas(T, P) + BVirial_Tsonopoulos(T, Tc, Pc, omega)
 
-@V.g
+@functor(var='V.g')
 def Abbott(T, P, Tc, Pc, omega):
     return ideal_gas(T, P) + BVirial_Abbott(T, Tc, Pc, omega)
 
-@V.g
+@functor(var='V.g')
 def Pitzer_Curl(T, P, Tc, Pc, omega):
     return ideal_gas(T, P) + BVirial_Pitzer_Curl(T, Tc, Pc, omega)
     
-@V.g
+@functor(var='V.g')
 def CRCVirial(T, P, a1, a2, a3, a4, a5):
     t = 298.15/T - 1.
     return ideal_gas(T, P) + (a1 + a2*t + a3*t**2 + a4*t**3 + a5*t**4)/1e6
@@ -680,9 +774,20 @@ def volume_gas_handle(handle, CAS, Tc, Pc, omega, eos):
 
 # %% Solids
 
-@V.s(ref='[12]_')
+@functor(var='V.s')
 def Goodman(T, Tt, V_l):
-    r'''
+    r"""
+    Create a functor of temperature (T; in K) that estimates the solid molar
+    volume (V.s; in m^3/mol) of a chemical using the Goodman method, as 
+    described in [12]_.
+    
+    Parameters
+    ----------
+    Tt : float
+        Triple point temperature [K].
+    V_l : float
+        Liquid molar volume [-].
+    
     Notes
     -----
     Calculates solid density at T using the simple relationship
@@ -702,7 +807,7 @@ def Goodman(T, Tt, V_l):
     >>> f(281.46)
     8.797191839062899
 
-    '''
+    """
     return (1.28 - 0.16*(T/Tt))*V_l
 
 @TPDependentHandleBuilder('V.s')
